@@ -159,31 +159,20 @@ env_content = f"""# [project_name] 环境变量配置
 # 应用配置
 APP_NAME=[project_name]
 APP_VERSION=[project_version]
-DEBUG=True
+APP_DEBUG=True
 
 # 服务器配置
-SERVER_HOST=0.0.0.0
-SERVER_PORT=8000
-
-# 数据库配置
-# DATABASE_URL=postgresql://user:password@localhost:5432/[project_name]
+APP_HOST=0.0.0.0
+APP_PORT=8000
 
 # Redis配置
 REDIS_HOST=localhost
 REDIS_PORT=6379
 REDIS_DB=0
 
-# 日志配置
-LOG_LEVEL=INFO
-LOG_FORMAT=%(asctime)s - %(name)s - %(levelname)s - %(message)s
-
 # CORS配置
-CORS_ORIGINS=http://localhost:3000,http://localhost:8000
+CORS_ORIGINS=*
 
-# JWT配置
-# JWT_SECRET_KEY=your-secret-key
-# JWT_ALGORITHM=HS256
-# JWT_EXPIRATION_TIME=3600
 """
 
 
@@ -198,12 +187,12 @@ def generate_basic_files(project_path, project_name, project_version):
     create_file(f"{project_path}/.dockerignore", dockerignore_content)
 
     # 创建.env文件
-    env_content = read_template_file(".env")
+    # env_content = read_template_file(".env")
     # 替换项目名称变量
-    env_content = env_content.replace("[project_name]", project_name).replace(
+    _env = env_content.replace("[project_name]", project_name).replace(
         "[project_version]", project_version
     )
-    create_file(f"{project_path}/.env", env_content)
+    create_file(f"{project_path}/.env", _env)
 
     # 创建requirements.txt文件
     requirements_content = read_template_file("requirements.txt")
@@ -231,9 +220,9 @@ def generate_config_files(project_path):
     config_init_content = read_template_file("src/config/__init__.py")
     create_file(f"{project_path}/src/config/__init__.py", config_init_content)
 
-    # 创建src/config/settings.py
-    settings_content = read_template_file("src/config/settings.py")
-    create_file(f"{project_path}/src/config/settings.py", settings_content)
+    # # 创建src/config/settings.py
+    # settings_content = read_template_file("src/config/settings.py")
+    # create_file(f"{project_path}/src/config/settings.py", settings_content)
 
 
 def generate_domain_files(project_path):
